@@ -3,7 +3,9 @@
 from __future__ import annotations
 from typing import IO, NamedTuple
 
+from mcipc.functions import json_serializable
 from mcipc.query.proto.common import MAGIC
+from mcipc.query.proto.common import NULL
 from mcipc.query.proto.common import decodeall
 from mcipc.query.proto.common import ip_or_hostname
 from mcipc.query.proto.common import random_session_id
@@ -38,6 +40,7 @@ class Request(NamedTuple):
                    challenge_token=challenge_token)
 
 
+@json_serializable
 class BasicStats(NamedTuple):
     """Basic statistics response packet."""
 
@@ -61,10 +64,10 @@ class BasicStats(NamedTuple):
         while True:
             body += file.read(1)
 
-            if len(body.split(b'\0')) == 7:
+            if len(body.split(NULL)) == 7:
                 break
 
-        *blocks, port_ip, _ = body.split(b'\0')
+        *blocks, port_ip, _ = body.split(NULL)
         motd, game_type, map_, num_players, max_players = decodeall(blocks)
         num_players = int(num_players)
         max_players = int(max_players)
@@ -73,17 +76,3 @@ class BasicStats(NamedTuple):
         return cls(
             type_, session_id, motd, game_type, map_, num_players, max_players,
             host_port, host_ip)
-
-    def to_json(self) -> dict:
-        """Returns a JSON-ish dict."""
-        return {
-            'type': self.type.value,
-            'session_id': self.session_id,
-            'motd': self.motd,
-            'game_type': self.game_type,
-            'map': self.map,
-            'num_players': self.num_players,
-            'max_players': self.max_players,
-            'host_port': self.host_port,
-            'host_ip': str(self.host_ip)
-        }
