@@ -1,5 +1,7 @@
 """Implementation of the camerashake command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.proxy import CommandProxy
 from mcipc.rcon.types import CamerashakeType
@@ -11,8 +13,13 @@ __all__ = ['CamerashakeProxy', 'camerashake']
 class CamerashakeProxy(CommandProxy):   # pylint: disable=R0903
     """Proxy for camera shake commands."""
 
-    def add(self, player: str, intensity: float = None, seconds: float = None,
-            shake_type: CamerashakeType = None) -> str:
+    def add(
+            self,
+            player: str,
+            intensity: Optional[float] = None,
+            seconds: Optional[float] = None,
+            shake_type: Optional[CamerashakeType] = None
+    ) -> str:
         """Used to enable a camera shaking effect."""
         return self._run('add', player, intensity, seconds, shake_type)
 
