@@ -1,5 +1,7 @@
 """Implementation of the clone command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.enumerations import MaskMode
 from mcipc.rcon.types import CloneMode, MaskMode as MaskModeHint, Vec3
@@ -8,9 +10,17 @@ from mcipc.rcon.types import CloneMode, MaskMode as MaskModeHint, Vec3
 __all__ = ['clone']
 
 
-def clone(self: Client, begin: Vec3, end: Vec3, destination: Vec3, *,
-          mask_mode: MaskModeHint = None, clone_mode: CloneMode = None,
-          tile_name: str = None, tile_data: int = None) -> str:
+def clone(
+        self: Client,
+        begin: Vec3,
+        end: Vec3,
+        destination: Vec3,
+        *,
+        mask_mode: Optional[MaskModeHint] = None,
+        clone_mode: Optional[CloneMode] = None,
+        tile_name: Optional[str] = None,
+        tile_data: Optional[int] = None
+) -> str:
     """Clones blocks from one region to another."""
 
     args = ['clone', begin, end, destination]
