@@ -1,5 +1,7 @@
 """Implementation of the ride command."""
 
+from typing import Optional
+
 from mcipc.rcon.be.types import FillType, RideRules, TeleportRules
 from mcipc.rcon.client import Client
 from mcipc.rcon.proxy import CommandProxy
@@ -11,9 +13,12 @@ __all__ = ['RideProxy', 'ride']
 class RideProxy(CommandProxy):
     """Proxy for ride related commands."""
 
-    # pylint: disable=W0621
-    def start_riding(self, ride: str, teleport_rules: TeleportRules = None,
-                     how_to_fill: FillType = None) -> str:
+    def start_riding(
+            self,
+            ride: str,
+            teleport_rules: Optional[TeleportRules] = None,
+            how_to_fill: Optional[FillType] = None
+    ) -> str:
         """Makes <riders> ride on <ride>."""
         return self._run('start_riding', ride, teleport_rules, how_to_fill)
 
@@ -25,13 +30,22 @@ class RideProxy(CommandProxy):
         """Makes entities that are riding on <rides> dismount."""
         return self._run('evict_riders')
 
-    def summon_rider(self, entity_type: str, spawn_event: str = None,
-                     name_tag: str = None) -> str:
+    def summon_rider(
+            self,
+            entity_type: str,
+            spawn_event: Optional[str] = None,
+            name_tag: Optional[str] = None
+    ) -> str:
         """Summons a rider."""
         return self._run('summon_rider', entity_type, spawn_event, name_tag)
 
-    def summon_ride(self, entity_type: str, ride_rules: RideRules = None,
-                    spawn_event: str = None, name_tag: str = None) -> str:
+    def summon_ride(
+            self,
+            entity_type: str,
+            ride_rules: Optional[RideRules] = None,
+            spawn_event: Optional[str] = None,
+            name_tag: Optional[str] = None
+    ) -> str:
         """Summons a ride."""
         return self._run('summon_ride', entity_type, ride_rules, spawn_event,
                          name_tag)
