@@ -1,5 +1,7 @@
 """Implements the testforblocks command."""
 
+from typing import Optional
+
 from mcipc.rcon.be.types import MatchMode
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import Vec3
@@ -8,8 +10,13 @@ from mcipc.rcon.types import Vec3
 __all__ = ['testforblocks']
 
 
-def testforblocks(self: Client, begin: Vec3, end: Vec3, destination: Vec3,
-                  match_mode: MatchMode = None) -> str:
+def testforblocks(
+        self: Client,
+        begin: Vec3,
+        end: Vec3,
+        destination: Vec3,
+        match_mode: Optional[MatchMode] = None
+) -> str:
     """Tests whether the blocks in two regions match."""
 
     return self.run('testforblocks', begin, end, destination, match_mode)
