@@ -1,6 +1,6 @@
 """Minecraft-specific client."""
 
-from rcon import Client
+from rcon import source
 
 from mcipc.rcon.functions import str_until_none
 
@@ -8,10 +8,9 @@ from mcipc.rcon.functions import str_until_none
 __all__ = ['Client']
 
 
-class Client(Client):  # pylint: disable=E0102
+class Client(source.Client):
     """An RCON client for Minecraft."""
 
-    # pylint: disable=W0221
     def run(self, command: str, *arguments: str) -> str:
         """Runs the command with additional checks."""
         return super().run(*str_until_none(command, *arguments))
