@@ -1,6 +1,6 @@
 """Implementation of th gamerule command."""
 
-from typing import Union
+from typing import Optional, Union
 
 from mcipc.rcon.client import Client
 
@@ -8,7 +8,11 @@ from mcipc.rcon.client import Client
 __all__ = ['gamerule']
 
 
-def gamerule(self: Client, rule: str, value: Union[bool, int] = None) -> str:
+def gamerule(
+        self: Client,
+        rule: str,
+        value: Optional[Union[bool, int]] = None
+) -> str:
     """Sets or queries a game rule value."""
 
     return self.run('gamerule', rule, value)
