@@ -1,5 +1,7 @@
 """Implementation of the experience and xp commands."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.proxy import CommandProxy
 from mcipc.rcon.types import XPUnit
@@ -11,11 +13,21 @@ __all__ = ['ExperienceProxy', 'experience', 'xp']
 class ExperienceProxy(CommandProxy):
     """Proxy for Experience commands."""
 
-    def add(self, targets: str, amount: int, unit: XPUnit = None) -> str:
+    def add(
+            self,
+            targets: str,
+            amount: int,
+            unit: Optional[XPUnit] = None
+    ) -> str:
         """Gives the target the specified amount of XP units."""
         return self._run('add', targets, amount, unit)
 
-    def set(self, targets: str, amount: int, unit: XPUnit = None) -> str:
+    def set(
+            self,
+            targets: str,
+            amount: int,
+            unit: Optional[XPUnit] = None
+    ) -> str:
         """Sets the XP of the target to the specified amount and units."""
         return self._run('set', targets, amount, unit)
 
