@@ -1,6 +1,6 @@
 """Implementation of the forceload command."""
 
-from typing import Union
+from typing import Optional, Union
 
 from mcipc.rcon.client import Client
 from mcipc.rcon.proxy import CommandProxy
@@ -14,13 +14,17 @@ class ForceloadProxy(CommandProxy):
     """Provides forceload-related sub commands."""
 
     # pylint: disable=C0103
-    def add(self, from_: Vec2, to: Vec2 = None) -> str:
+    def add(self, from_: Vec2, to: Optional[Vec2] = None) -> str:
         """Forces the chunk at the <from> position (through to <to> if set) in
         the dimension of the command's execution to be loaded constantly.
         """
         return self._run('add', from_, to)
 
-    def remove(self, from_or_all: Union[Vec2, 'all'], to: Vec2 = None) -> str:
+    def remove(
+            self,
+            from_or_all: Union[Vec2, 'all'],
+            to: Optional[Vec2] = None
+    ) -> str:
         """Unforces the chunk at the <from> position (through to <to> if set)
         in the dimension of the command's execution to be loaded constantly.
         """
@@ -32,7 +36,7 @@ class ForceloadProxy(CommandProxy):
 
         return self._run('remove', from_or_all, to)
 
-    def query(self, pos: Vec2 = None) -> str:
+    def query(self, pos: Optional[Vec2] = None) -> str:
         """If chunk coordinates are given, displays the specified chunk in the
         dimension of the command's execution is force loaded; otherwise, lists
         which chunks in the dimension of the command's execution are force
