@@ -1,5 +1,7 @@
 """Implementation of the schedule command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.je.types import ScheduleMode, Time
 from mcipc.rcon.proxy import CommandProxy
@@ -11,8 +13,12 @@ __all__ = ['ScheduleProxy', 'schedule']
 class ScheduleProxy(CommandProxy):
     """Proxy for schedule sub-commands."""
 
-    def function(self, function: str, time: Time,
-                 mode: ScheduleMode = None) -> str:
+    def function(
+            self,
+            function: str,
+            time: Time,
+            mode: Optional[ScheduleMode] = None
+    ) -> str:
         """Adds a schedule."""
         return self._run('function', function, time, mode)
 
