@@ -1,5 +1,7 @@
 """Implementation of the spawnpoint command."""
 
+from typing import Optional
+
 from mcipc.rcon.client import Client
 from mcipc.rcon.types import Vec3
 
@@ -7,8 +9,12 @@ from mcipc.rcon.types import Vec3
 __all__ = ['spawnpoint']
 
 
-def spawnpoint(self: Client, targets: str = None, pos: Vec3 = None,
-               angle: float = None) -> str:
+def spawnpoint(
+        self: Client,
+        targets: Optional[str] = None,
+        pos: Optional[Vec3] = None,
+        angle: Optional[float] = None
+) -> str:
     """Sets the spawn point for a player."""
 
     return self.run('spawnpoint', targets, pos, angle)
