@@ -1,6 +1,6 @@
 """Command proxies."""
 
-from __future__ import annotations
+from typing import Type, TypeVar
 
 from mcipc.rcon.functions import until_none
 from mcipc.rcon.client import Client
@@ -9,7 +9,10 @@ from mcipc.rcon.client import Client
 __all__ = ['CommandProxy']
 
 
-class CommandProxy:     # pylint: disable=R0903
+DelegatedType = TypeVar('DelegatedType')
+
+
+class CommandProxy:
     """A basic command proxy."""
 
     __slots__ = ('_client', '_args')
@@ -22,7 +25,7 @@ class CommandProxy:     # pylint: disable=R0903
     def __repr__(self):
         return f'{type(self).__name__}({self._client}, {self._args})'
 
-    def _proxy(self, cls: type, *args: str) -> CommandProxy:
+    def _proxy(self, cls: Type[DelegatedType], *args: str) -> DelegatedType:
         """Returns a sub-proxy."""
         return cls(self._client, *self._args, *until_none(args))
 
