@@ -4,13 +4,13 @@ from re import fullmatch
 from typing import NamedTuple
 
 from mcipc.functions import json_serializable
-from mcipc.rcon.errors import NoPlayerFound
+from mcipc.rcon.exceptions import NoPlayerFound
 
 
 __all__ = ['KickedPlayer', 'parse']
 
 
-REGEX = 'Kicked (.*): (.*)'
+REGEX = r'Kicked (.*): (.*)'
 
 
 @json_serializable
